==> Pyrogram-1.0.2-py3-none-any.whl: pyrogram/raw/base/message_user_vote.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

MessageUserVote = Union[raw.types.MessageUserVote, raw.types.MessageUserVoteInputOption, raw.types.MessageUserVoteMultiple]


# noinspection PyRedeclaration
class MessageUserVote(TLObject):  # type: ignore
    """This base type has 3 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`MessageUserVote <pyrogram.raw.types.MessageUserVote>`
            - :obj:`MessageUserVoteInputOption <pyrogram.raw.types.MessageUserVoteInputOption>`
            - :obj:`MessageUserVoteMultiple <pyrogram.raw.types.MessageUserVoteMultiple>`
    """

    QUALNAME = "pyrogram.raw.base.MessageUserVote"

==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/base/message_user_vote.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

MessageUserVote = Union[raw.types.MessageUserVote, raw.types.MessageUserVoteInputOption, raw.types.MessageUserVoteMultiple]


# noinspection PyRedeclaration
class MessageUserVote:  # type: ignore
    """This base type has 3 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`MessageUserVote <pyrogram.raw.types.MessageUserVote>`
            - :obj:`MessageUserVoteInputOption <pyrogram.raw.types.MessageUserVoteInputOption>`
            - :obj:`MessageUserVoteMultiple <pyrogram.raw.types.MessageUserVoteMultiple>`
    """

    QUALNAME = "pyrogram.raw.base.MessageUserVote"
